#
# functions
# management of time series 
# check for gaps
# find values/index by time
# extract one month from data
#-----------------------------------------------
#
# check for gaps and irregularities
#
check_gaps <- function(time_series,time_step)
{
 for(it in 2:length(time_series[,1]))
  {
    delta = difftime(time_series[it,1], time_series[it-1,1],units="secs")
    if(delta!=time_step) 
    print(paste("                  Gap at",time_series[it,1],time_series[it-1,1]))  
  }
}

#-----------------------------------------------------
# 
# find the index of a specific time in the time series
#

find_time <- function(time_series,time_value,start)
{
# speedup -> start with serach loop as late as possible
  if(start==1)
   {if((time_value - time_series[270*24,1])>0)      {start = 270*24;}
    else if((time_value - time_series[180*24,1])>0) {start = 180*24;}
    else if((time_value - time_series[90*24,1])>0)  {start = 90*24; }
   }
# loop to find first time older then given (non positive difference)
 for(it in start:length(time_series[,1]))
  {
    difftime = time_value - time_series[it,1]
    if(difftime<=0)return(it);  
  }
 return(-1)
}

#--------------------------------------------------------
#
# extract one month from a one year time series
#
extract_month_subset <- function(time_series,month_index)
{
# starttime by 1st day of month 00:00:00 
  starttime = as.POSIXct(sprintf("2010-%2.2d-01 00:00:00",month_index),tz="UTC")
  startindex = find_time(time_series,starttime,1)
# endtime: begin of next months - 1 or in case of december index of last data set
  if(month_index!=12) {
  endtime = as.POSIXct(sprintf("2010-%2.2d-01 00:00:00",month_index+1),tz="UTC")
  endindex = find_time(time_series,endtime,startindex)-1 }
  else endindex = length(time_series[,1])
# subset with start/endindex of the month   
  month_time_series = subset(time_series[startindex:endindex,]) 
  return(month_time_series) 
}


