#
# functions
# plotting of time series 
# plot for one year
# plot for one month
# add additional time series line
# add mean value line
#
#-----------------------------------------------
# global parameter
#
time_origin = 0

#-----------------------------------------------
#
# plot one time series for one year
#
plot_year <- function(time_series,scalar_type)
{
# color
  color_01="darkblue"
  
# type of diagram 
  if(scalar_type=="Ta") 
  { title = "Air Temperature at 2 m high"
    unit = "Celsius"
    range = c(-25,40)
  }
  else if (scalar_type=="Ts")
  { title = "Soil Temperature at -5 cm"
    unit = "Celsius"
    range = c(-10,50)
  }
  else
  { title = "Precipitation"
    unit = "mm"
    range = c(0,25)
  } 
 year = strftime(time_series[1,1],format="%Y")
  
# plot diagram without content
  plot(NA,NA, type="l",xaxt="n",main=title, ylab=unit, xlab="Week", xlim=c(time_series[1,1],time_series[length(time_series[,1]),1]),ylim=range, col=color_01)
  legend("bottomleft",year,text.col=color_01,yjust=0)  
# grid in the background
  timestep_number = length(time_series[,1])
  abline(h=(seq(range[1],range[2],5)),  col="lightgrey", lty="dotted")
  abline(v=(seq(time_series[1,1],time_series[timestep_number,1]+7*24*3600,7*24*3600)), col="lightgrey", lty="dotted")
# time axis
  ticks <- seq(time_series[1,1],time_series[timestep_number,1]+7*24*3600,7*24*3600)
  tn = (timestep_number)/(24*7) +2
  t = seq(1:tn)
  ts=sprintf("%d",t-trunc((t-1)/tn)*tn)
  axis(1, at=(ticks), labels=ts)
# line  
  lines(time_series,col=color_01)
}

#-----------------------------------------------
#
# plot a one month time series
#

plot_month <- function(time_series,month_index,scalar_type)
{
# extraction of month sub time series
 month_time_series = extract_month_subset(time_series,month_index)
 time_origin <<- as.integer(month_time_series[1,1])

# color
 color_01="darkblue"

# type of diagram 
 if(scalar_type=="Ta") 
  { title = "Air Temperature at 2 m high"
    unit = "Celsius"
    range = c(-25,40)
  }
  else if (scalar_type=="Ts")
  { title = "Soil Temperature at -5 cm"
    unit = "Celsius"
    range = c(-10,50)
  }
 else
 { title = "Precipitation"
   unit = "mm"
   range = c(0,25)
 }
 month= strftime(month_time_series[1,1],format="%B")
 
# plot diagram without content
 plot(NA,NA, type="l",xaxt="n",main=title, ylab=unit, xlab="Day", xlim=c(month_time_series[1,1],month_time_series[length(month_time_series[,1]),1]),ylim=range, col=color_01)
 legend("bottomleft",month,text.col=color_01,yjust=0)  

# grid in the background
 timestep_number = length(month_time_series[,1])
 abline(h=(seq(range[1],range[2],5)),  col="lightgrey", lty="dotted")
 abline(v=(seq(month_time_series[1,1],month_time_series[timestep_number,1]+24*3600,24*3600)), col="lightgrey", lty="dotted")

 # time axis
 ticks <- seq(month_time_series[1,1],month_time_series[timestep_number,1]+24*3600,24*3600)
 tn = (timestep_number)/(24) +1
 t = seq(1:tn)
 ts=sprintf("%d",t-trunc((t-1)/tn)*tn)
 axis(1, at=(ticks), labels=ts)

# plot lines for time series
 lines(month_time_series,col=color_01)
 plot_mean_value(month_time_series,color_01)
}

#-----------------------------------------------
#
# add onle line for a month plot
#
plot_line_month <- function(time_series,month_index)
{
# extraction of month sub time series
 month_time_series = extract_month_subset(time_series,month_index)
 month= strftime(month_time_series[1,1],format="%B")
 
# move to time_orign of basic time series 
 time_difference   = as.integer(month_time_series[1,1])- as.integer(time_origin)
 month_time_series[,1] = month_time_series[,1] - time_difference 

# color
 color_01="darkgreen"
 
# plot lines and meanvalue 
 lines(month_time_series,col=color_01)
 plot_mean_value(month_time_series,color_01)
 legend("bottomright",month,text.col=color_01,yjust=0)  
}

#-----------------------------------------------
#
# plot line for mean value with text
#
plot_mean_value <- function(month_time_series,color_01)
{
 meanvalue = mean(month_time_series[,2])
 timestep_number = length(month_time_series[,1])
 lines(c(month_time_series[1,1],month_time_series[timestep_number,1]),c(meanvalue,meanvalue),col=color_01)
 text(month_time_series[1,1],meanvalue,sprintf("%.2f",meanvalue),col=color_01,pos=1)
}

